import{_ as r,o as t,c as o,L as s,a}from"./BLm-LuZL.js";const c={},n={class:"text-center rounded border-2 border-dashed border-gray-300 dark:border-gray-700 bg-gray-50 dark:bg-gray-800 py-4 text-sm"},d=a("span",{class:"text-gray-400"}," Empty ",-1);function _(e,l){return t(),o("div",n,[s(e.$slots,"default",{},()=>[d])])}const g=r(c,[["render",_]]);export{g as _};
